# Table of Contents

- [servicenow-integration](<./servicenow-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [ServiceNow Integration](<./ServiceNow-Integration.md>)
  - [Overview](<./ServiceNow-Integration/Overview.md>)
  - [Prerequisites](<./ServiceNow-Integration/Prerequisites.md>)
  - [Communication with ServiceNow](<./ServiceNow-Integration/Communication-with-ServiceNow.md>)
  - [Core Concepts](<./ServiceNow-Integration/Core-Concepts.md>)
  - [Sync Mode](<./ServiceNow-Integration/Sync-Mode.md>)
  - [Supported Configurations](<./ServiceNow-Integration/Supported-Configurations.md>)
  - [Default Mapping](<./ServiceNow-Integration/Default-Mapping.md>)
  - [Default Mapping (SAM Pro)](<./ServiceNow-Integration/Default-Mapping-SAM-Pro.md>)
  - [Legacy Configuration](<./ServiceNow-Integration/Legacy-Configuration.md>)
  - [Custom Configurations](<./ServiceNow-Integration/Custom-Configurations.md>)
  - [Synchronization Through a Mirror Table](<./ServiceNow-Integration/Synchronization-Through-a-Mirror-Table.md>)
  - [Frequently Asked Questions](<./ServiceNow-Integration/Frequently-Asked-Questions.md>)
  - [Was this page helpful?](<./ServiceNow-Integration/Was-this-page-helpful.md>)
